@@ -122,9 +122,7 @@ class ClInstallAction(Action):
         {'name': 'prepare_boot',
          'message': __("Preparing the system for reboot"),
          'method': 'Install.prepareBoot(cl_target)',
-         'condition': lambda dv: (dv.Get('os_install_mbr') or
-                                  dv.Get('os_install_uefi_set') == 'on') and
-                                 dv.Get('os_install_pxe') == 'off'},
+         'condition': lambda dv: dv.Get('os_install_root_type') == "flash"},
         # отключение исходного дистрибутива
         {'name': 'umount_source',
          'message': __("Letting go the source distribution"),
