@@ -912,7 +912,7 @@ class VariableOsInstallPxe(Variable):
                 try:
                     config = cl_ini_parser.iniParser(env_fn)
                     val = config.getVar('server', 'sr_dhcp_set')
-                    if val.encode('utf-8') == "on":
+                    if val.encode('utf-8') == "on" or val == "on":
                         return
                 except Exception:
                     pass
